#!/usr/bin/env python3

import evdev
import sys
import time


# Obtain an object for the motor.
for path in evdev.list_devices():
    device = evdev.InputDevice(path)
    if evdev.ecodes.EV_FF in device.capabilities():
        break
else:
    sys.stderr.write('Failed to find the haptic motor.\n')
    sys.exit(1)

# Define a rumble effect.
rumble = evdev.ff.Rumble(strong_magnitude=0xff, weak_magnitude=0xffff)

# Create an effect type and duration.
effect_type = evdev.ff.EffectType(ff_rumble_effect=rumble)
duration = 1000

# Create the effect itself.
effect = evdev.ff.Effect(evdev.ecodes.FF_RUMBLE, -1, 0,
                         evdev.ff.Trigger(0, 0),
                         evdev.ff.Replay(duration, 0),
                         effect_type)

# Upload the effect to the device and obtain an ID.
effect_id = device.upload_effect(effect)

# Write the event to the device to play the effect just once.
device.write(evdev.ecodes.EV_FF, effect_id, 1)

time.sleep(duration / 1000.0)

# Erase the effect once we are finished with it.
device.erase_effect(effect_id)
